% From Jean-Marc Belloir, Vincent Goiffon, Cdric Virmontois, Mlanie Raine, Philippe Paillet, Olivier Duhamel, Marc Gaillardin, Romain Molina, Pierre Magnan, and Olivier Gilard, "Pixel pitch and particle energy influence on the dark current distribution of neutron irradiated CMOS image sensors," Opt. Express 24, 4299-4315 (2016)
% author: Alexandre Le Roch

clear all
close all
clc

% Last modification: % 06/17/2022
display('#############################################')
display('Dark Current Analysis Tool : Histograms and Model ')
display('v1.0')
display('contact: alexandre.leroch@nasa.gov / vincent.goiffon@isae-supaero.fr')
display('#############################################')

%% Adjustable parameters
DisplacementDamageDose = 5000; %TeV/g
Vdep = 100; %Depletion volume in m3
BinSize = 400; %e-/s for histogram creation/representation
PixelNumber = 1e6; %number of pixels in the image sensor array

% According to Belloir paper nuDark is about 4100 e-/s at 22C after 6
% weeks annealing. If the measurement temperature is several degree above
% or below 22C, a new nuDark value shall be estimated using a typical 0.63eV
% activation energy. If the annealing period duration is very different
% from 6 weeks (i.e. less than a week or more than 3 months), a new nuDark
% value shall be estimated based on existing displacement damage induced
% dark current data available in litterature, such as:
% Srour, J. R., & Lo, D. H. (2000). Universal damage factor for radiation-induced dark current in silicon devices. IEEE Transactions on Nuclear Science, 47(6), 2451-2459.
% Raine, M., Goiffon, V., Paillet, P., Duhamel, O., Girard, S., Gaillardin, M., ... & Magnan, P. (2014). Exploring the kinetics of formation and annealing of single particle displacement damage in microvolumes of silicon. IEEE Transactions on Nuclear Science, 61(6), 2826-2833.

nuDark_6weeks_22C = 4100; %e-/s depends only on measurement temperature (activation energy ~0.63eV) and annealing time

%% Fixed parameters
nuDark = 4100; %e-/s (4100 6weeks_22C)
KdarkSrour_6weeks_22C = 0.104;% e-/s/m3/(TeV/g) at 22C and 6 weeks annealing (0.104)
gammaDark = KdarkSrour_6weeks_22C/nuDark; % 1/m3/(TeV/g) assumed independent of temperature and annealing

%% Exponential law generation
x = 0:BinSize:100000*BinSize; % in e-/s
x = x+(BinSize/2);
pdf = (1/nuDark*exp(-x/nuDark));
figure('Name','Dark Current Increase Probability Density Function');
semilogy(x,pdf);

%% Computation of convolutions

muDark = gammaDark * Vdep * DisplacementDamageDose; % without unit since it represents the mean number of interactions per pixel

Idark_max = 1e5;% Max value to consider
max_conv = 20;% number of convolutions to consider. 
x = x(1:Idark_max);

% Reshaped pdf
pdf_plot=pdf(1:Idark_max);
figure('Name','Convolutions');
semilogy(x,pdf_plot);
hold on;

% First iteration
IdarkModelNormalized = poisspdf(1,muDark)*pdf_plot;
semilogy(x,IdarkModelNormalized);

convo_temp = pdf;
hold on;

% Other convolutions starting at 2nd
for i=2:max_conv
    convo_temp=conv(convo_temp,pdf)*BinSize;
    convo_temp1=convo_temp(1:Idark_max); % Reshape the number of data points to Idark_max
    IdarkModelNormalized = IdarkModelNormalized + poisspdf(i,muDark)*convo_temp1;
    semilogy(x,IdarkModelNormalized);
    hold on;
end
hold off;
%***********************************

% Constructing the full distribution with non impacted pixels
Dirac = zeros(1,Idark_max);
Dirac(1)=1;
IdarkModelNormalized_2 = IdarkModelNormalized + poisspdf(0,muDark)*Dirac/BinSize; % Normalized distribution to be used

%% Nomalized distribution
figure('Name','Normalized dark current increase generated histogram');
semilogy(x,IdarkModelNormalized_2);

%% Distribution adapted to experimental data 
IdarkModel = IdarkModelNormalized_2*PixelNumber*BinSize; %need to multiply by BinSize to obtain an histogram comparable to the experimental one
pdf_plot2 = pdf_plot*PixelNumber*BinSize;

figure('Name','Dark current increase generated histogram TO BE USED');
semilogy(x,IdarkModel);
xlabel('Dark Current Increase in e-/s')
ylabel('Pixel count')
ax=gca;
set(ax,'yscale','log');

%% axis optimization
Ymax = ceil(log10(max(IdarkModel)));
Ymax = 10^(Ymax);
Ymin = Ymax/10000;
Xmin = 0;
Xmax = 10*nuDark*muDark;
axis([Xmin Xmax Ymin Ymax]);

%% Data to use
% array to copy for comparison with measurement data
DATA_OUT = [x ; IdarkModel];